Enum BitcoinFormat

pub enum BitcoinFormat {
    P2PKH,
    P2WSH,
    P2SH_P2WPKH,
    Bech32,
}
Represents the format of a Bitcoin address

Variants



P2PKH

Pay-to-Pubkey Hash, e.g. 1NoZQSmjYHUZMbqLerwmT4xfe8A6mAo8TT



P2WSH

Pay-to-Witness-Script Hash, e.g. 347N1Thc213QqfYCz3PZkjoJpNv5b14kBd



P2SH_P2WPKH

SegWit Pay-to-Witness-Public-Key Hash, e.g. 34AgLJhwXrvmkZS1o5TrcdeevMt22Nar53



Bech32

Bech32, e.g. bc1pw508d6qejxtdg4y5r3zarvary0c5xw7kw508d6qejxtdg4y5r3zarvary0c5xw7k7grplx

Implementations

Source

impl BitcoinFormat

pub fn to_address_prefix<N: BitcoinNetwork>(&self) -> Vec<u8>

Returns the address prefix of the given network.

pub fn from_address_prefix(prefix: &[u8]) -> Result<Self, AddressError>

Returns the format of the given address prefix.

pub fn from_extended_private_key_version_bytes( prefix: &[u8], ) -> Result<Self, ExtendedPrivateKeyError>

Returns the network of the given extended private key version bytes. https://github.com/satoshilabs/slips/blob/master/slip-0132.md

pub fn from_extended_public_key_version_bytes( prefix: &[u8], ) -> Result<Self, ExtendedPublicKeyError>

Returns the network of the given extended public key version bytes. https://github.com/satoshilabs/slips/blob/master/slip-0132.md